/*

  This file is part of the Node Digest.

  Node Digest is free software: you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the Free
  Software Foundation, either version 3 of the License, or (at your option)
  any later version.

  Node Digest is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with Node Digest . If not, see <https://www.gnu.org/licenses/>.

*/

/*
  eslint-disable
  canonical/filename-match-exported
*/

import {
  fixupPluginRules
} from '@eslint/compat';
import {
  recommended as canonicalJSXAlly
} from 'eslint-config-canonical/jsx-a11y';
import {
  recommended as canonicalReact
} from 'eslint-config-canonical/react';
import * as cssModulesPlugin from 'eslint-plugin-css-modules';
import reactPlugin from 'eslint-plugin-react';

const cssModulesPluginFixed = {
  ...cssModulesPlugin.configs.recommended,
  files: [
    '**/*.{js,ts,jsx,tsx}'
  ],
  plugins: {
    'css-modules': fixupPluginRules(cssModulesPlugin)
  }
};

const reactConfigs = [
  cssModulesPluginFixed,
  {
    ...reactPlugin.configs.flat.recommended,
    files: [
      '**/*.{js,ts,jsx,tsx}'
    ],
    settings: {
      react: {
        version: 'detect',
      },
    }
  },
  {
    ...canonicalReact[0],
    files: [
      // js,ts needed until hooks supported outside jsx
      '**/*.{js,ts,jsx,tsx}'
    ],
    plugins: {
      'react-hooks': canonicalReact[0].plugins['react-hooks']
    },
    rules: {
      ...canonicalReact[0].rules,
      'react/forbid-component-props': 'off',
      'react/no-unknown-property': [
        'error',
        {
          ignore: [
            'styleName'
          ]
        }
      ]
    },
    settings: {
      react: {
        version: 'detect',
      },
    }
  },
  canonicalJSXAlly[0]
];

export default reactConfigs;
